function [K, L] = aggreg(iniPop, popGrowth, gr, wt, a, h, Debt, ax,vhx)
% aggreg: Individual -> aggregate factor supplies; bgp only
% ---------------------------------------
% TASK:
%  Individual -> aggregate factor supplies; bgp only
% IN:
%  (vectors are row vectors)
%  iniPop  = initial population
%  popGrowth   = population growth rate + 1
%  gr          = growth rate of per capita values
%  wt, a, h    = representative individual's supplies of labor, assets,
%                and human capital
%  Debt        = government debt; K = assets - Debt
%  ax          = wealth from investing in h1
%  vhx         = eff. labor used in h1 investment; by age of generation 1
% OUT:
%  aggregate K,L

% ERRORS:
%
% TEST:
%  t_aggr
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    dbg = 0;

% *******  INPUT CHECK  ********


    T = length(wt);
    if isempty(ax)
        age1 = 0;
    else
        age1 = length(ax)+1;
    end


% *** Population size ***
%  earlier generations are smaller

   popul = seqm(iniPop, 1/popGrowth, T);

% *** Factor to adjust for growth ***

   grFactor = seqm(1, 1/gr, T);
   grn = gr * popGrowth;


% *** Aggregation ***
%  First compute the vectors of individual supplies:

   effLabor = popul .* wt .* h .* grFactor;
   capital  = popul .* a  .* grFactor;
   if age1 > 1
     % ** Subtract debt of agents not yet "born" (ax)
     xAsset = aggreg2(ax, grn, iniPop);
     % Labor not supplied because of production of h1
     xLabor = aggreg2(vhx, grn, iniPop);
   else
     xAsset  = 0;
     xLabor = 0;
   end

%  Then sum over ages:
   L = sum(effLabor) - xLabor;
   K = sum(capital) - Debt + xAsset;



% *************  TEST SECTION  ********************
% ** computation of xAsset and xLabor is tested in aggreg2

if dbg > 0
    T = length(a);
    K2 = 0;
    L2 = 0;
    for i = 1 : T
        K2 = K2 + a(i) * iniPop / grn^(i-1);
        L2 = L2 + wt(i)*h(i) * iniPop / grn^(i-1);
    end

    K2 = K2 - Debt + xAsset;
    L2 = L2 - xLabor;

    if notequal( [K,L], [K2,L2], 1e-6 )
        warnmsg('Aggreg: Computation of K, L differs')
        K
        K2
        L
        L2
        keyboard
    end
end

% *** end function ***
