function bgpchk(calNo, calBgp, bgpNo)
% Consistency check of bgp
% ---------------------------------------
% TASK:
%  Check ALL conditions characterizing bgp
%  The household problem is not checked (this is done in og1bgp)

% IN:
%   standard characterization of bgp

% AUTHOR: Lutz Hendricks, 1993-97
% ---------------------------------------

% *** CONSTANTS ***

global UNDEFINED
global popGrowth tb hcAge hcInherit yearsOfLife iniAge bb iniPop
global hhLife yPerPd h1Invest Tx T1 tBequ
global twAdjustsG tkAdjustsG DYAdjustsG TrYAdjustsG GYAdjustsG UNCHANGED
global ddk bequ sig
dbg = 100;
toler = 1e-4;

disp(' ')
disp('------  BgpChk  ----------------------------------------------')


% **********  Load BGP + Calibration  ****************************
% ** suffix 0 indicates loaded variable

   paraload(calNo, calBgp);
   T = hhLife;
   ageDiff = tb - 1;

   [priceS,agS,hhS, K_,L_,gr_,Pol0Vec, mu0,phiX0_, c0, l0, v0, a0, h0, x0, util0,...
      BT0, phi00,valAbil00, vhx0,ax0,hx0,xx0]...
      = bgpload(calNo,calBgp,bgpNo,dbg);

   K0  = agS.K;
   L0  = agS.L;
   gr0 = agS.gr;
   dist = agS.dist;
   hAvg = agS.hAvg;

   B10   = hhS.B1;
   phiX0 = hhS.phiX;
   Lambda0 = hhS.Lambda;
   vh1Child0 = hhS.vh1Child;
   hT10 = hhS.hT1;

   [G, Gv, Gx, Gh, Gz] = Gf( v0, x0, h0, hAvg .* gr0.^(0:T-1), 1 );




% **********************  CHARACTERIZE BGP  ******************************

   [tax0, kDeduct,xDeduct,xEarn, taxAdj0] = bsetting(bgpNo, dbg);
   tax0(taxAdj0) = Pol0Vec(taxAdj0);

   [tw0,tk0,TrY0,GY0,tc0,to0,DY0,sx0,tmp,tmp,taxb0,sxx0,twx0] = taxvec(tax0);

   popSize = popsize( iniPop, popGrowth, T );
   oldIdx  = T1+1:T;
   T1idx   = 1:T1;


   [ Y0, MPK0, MPL0 ] = prodfct(K0,L0);
   Ynet0 = Y0 - ddk.*K0;
   D0 = DY0 .* Y0;
   wt0 = 1 - l0 - v0;
   Tr0 = TrY0 * Ynet0;


   % **********  Growth Factors  ***********************
   % ** These factors have to be applied to the representative agents'
   % ** profiles to obtain values for generations as function of age.
   nV   = seqm(1, 1/popGrowth, T);
   grV  = seqm(1, 1/gr0, T);
   grnV = seqm(iniPop, 1/gr0/popGrowth, T);
   popVec = iniPop .* nV;
   totalPop = popsize( iniPop, popGrowth, T );



% =============================  CONSISTENCY CHECK  ==============================


% *****************  AGGREGATES  *************************************

   % *********  GROWTH RATE  **********
   hVec = [h0, hT10];
   grChk = grrate(hVec, hx0, hAvg, dbg);
   if notequal(gr0, grChk, 1e-3)
       disp('--- Growth rates differ ---')
       disp(sprintf(' Loaded: %5.3f      Computed: %5.3f', gr0, grChk));
   end



   % **********  Generation variables  *****************
   % Cross-section aggregates are simply sums of these

    a = a0 .* grnV;
    h = h0 .* grnV;
    x = x0 .* grnV;
    c = c0 .* grnV;

    l = l0 .* popVec;
    v = v0 .* popVec;
    wt= wt0.* popVec;
    wth = (wt0.*h0) .* grnV;

    % ** Investment in h1: Aggregates
    if h1Invest == 1
%        grVecx = iniPop .* mseqend(gr0*popGrowth, 1/gr0/popGrowth, age1-1);
%        ax = ax0 .* grVecx;
%        vhx = vhx0 .* grVecx;
        axAggr  = aggreg2(ax0,  gr0*popGrowth, iniPop);
        vhxAggr = aggreg2(vhx0, gr0*popGrowth, iniPop);
    else
        axAggr  = 0;
        vhxAggr = 0;
    end


   % **********  Aggregates  ***************************

    Assets = sum(a) + axAggr;
    Cons   = sum(c);
    XEd    = sum(x);
    L      = sum( wth ) - vhxAggr;
    K      = Assets - D0;

    [ Y, MPK, MPL ] = prodfct(K,L);
    Ynet = Y - ddk.*K;

    hAvg = aggregx(iniPop, popGrowth, gr0, h0) ./ totalPop;

    if abs( K/K0-1 ) > toler
       s_compar( 'K differs', K, K0, 'p' );
    end
    if abs( Y/Y0-1 ) > toler
       s_compar( 'Y differs', Y, Y0, 'p' );
    end
    if abs( L/L0-1 ) > toler
       s_compar( 'L differs', L, L0, 'p' );
    end
    if abs( Ynet/Ynet0-1 ) > toler
       s_compar( 'Ynet differs', Ynet, Ynet0, 'p' );
    end

    % This is really redundant: another way of aggregating
    [K2, L2] = aggreg(iniPop, popGrowth, gr0, wt0, a0, h0, D0, ax0,vhx0);
    if abs( K2/K0-1 ) > toler
       s_compar( 'K aggregation', K2, K0, 'p' );
    end
    if abs( L2/L0-1 ) > toler
       s_compar( 'L aggregation', L2, L0, 'p' );
    end

    %  ****  Comparison ex h1 investment  ****
    [K3, L3] = aggreg(iniPop, popGrowth, gr0, wt0, a0, h0, D0, 0,0);
    K4 = sum(a)-D0;
    L4 = sum(wth);
    if abs( K3/K4-1 ) > toler
       s_compar( 'K3 / K4 ', K3, K4, 'p' );
    end
    if abs( L3/L4-1 ) > toler
       s_compar( 'L3 / L4', L3, L4, 'p' );
    end


    % ** Compare computation of earnings from individual vs. aggregate
    % ** data
    EARN = MPL .* L - XEd.*xEarn;
    LOld = sum( wth(oldIdx) );
    XOld = sum( x(oldIdx) );
    EARNOld = MPL .* LOld - XOld.*xEarn;

    earn = wth .* MPL - x.*xEarn;
    earnAggr = sum(earn) - MPL * vhxAggr;
    earnOld = earn(oldIdx);
    if notequal(EARN, earnAggr, 1e-5)
        EARN
        earnAggr
        disp('!! Earnings different!!')
    end
    if notequal(EARNOld, sum(earnOld), 1e-5)
        EARNOld
        earnOld
        disp('!! Old Earnings different!!')
    end


    % This cross-checks consistency of two functions
    [r,w, tl] = bgprw( MPK, MPL, tk0,tw0,0,to0, kDeduct, ddk,T1, T );
    r = r(1);
    w = w(1);
    tmp = netr(MPK, tk0, kDeduct, ddk);
    if notequal( r(1), tmp )
        warnmsg('bgprw ~= netr')
    end


% ********************  GOVERNMENT  ***************************************

    % *** Compare loaded policies with spec ***
    % ** Loaded: Pol0Vec in standard format
    diff = tax0' - Pol0Vec;
    if max(abs( diff )) > toler
        warnmsg('Loaded policy differs from tax0')
        disp('tax0:')
        disp(tax0')
        disp('Loaded:')
        disp(Pol0Vec)
    end



    G  = GY0 * Y;
    Tr = TrY0 * Ynet;
    D  = [ D0, D0*gr0*popGrowth ];

    [Deficit,GRev,GSpend] = govbc(G,Tr,D, Cons,XEd,K,L,LOld,XOld,...
         tw0,tk0,to0,tc0,sx0, xEarn,xDeduct, kDeduct,ddk, agS.Xx,sxx0);

    if abs(Deficit) > toler
        disp(' ')
        disp('--- Government budget ---')
        tmp = sprintf('Spend.= %5.3f   Rev = %5.3f -> Deficit = %5.3f',...
            GSpend, GRev, Deficit);
        disp(tmp);
        %tmp = sprintf(' r-grn+1 = %5.3f', r-gr0*popGrowth+1);
        %disp(tmp)
    end


% ***********************  BEQUEST CONDITION  ******************************

if bequ > 0  &  BT0 > 0
   LHS = bequ * (bb * (1+r(1)))^(T-tBequ);
   RHS = gr0^(sig*ageDiff);
   if distance(LHS, RHS) > 1e-3
      disp(' ')
      disp('--- Bequest condition violated ---')
      tmp = sprintf('LHS: %6.3f     RHS: %6.3f', LHS, RHS);
      disp(tmp);
   end

   % ***** Size of bequest: left vs. received ******
   nChildren = popGrowth ^ ageDiff;
   dev = BT0 / B10 / gr0^ageDiff / nChildren - 1;
   if abs(dev) > toler
      warnmsg(sprintf('Invalid B1 vs. BT. Deviation: %f', dev));
   end

   % ***** Compare MU of child and parent *****
   [ tmp, muParent ] = ufct( c0(T), l0(T) );
   if tBequ > 0
      [ tmp, muChild  ] = ufct( c0(tBequ)*gr0^ageDiff, l0(tBequ) );
      dev = muChild * bequ / muParent - 1;
   elseif tBequ == 0
      % Child born one year after parent dies
      [ tmp, muChild  ] = ufct( c0(1)*gr0^ageDiff, l0(1) );
      dev = bb * (1+r) * muChild * bequ / muParent - 1;
   else
      abort([ mfilename, ': Invalid tBequ' ]);
   end
   if abs(dev) > toler
      warnmsg(sprintf('Invalid MU of bequest. Deviation: %f', dev));
   end
end


% *************  INVESTMENT IN H1  ********************

if h1Invest == 1
   wx  = MPL * (1-twx0);
   cxx = x_cost(tl(1), sxx0, 0, 0);
   hAvgx = mseqend(hAvg(1)/gr0, gr0, Tx);
   dV_da1 = Lambda0;
   dV_dh1 = phi00;
   [maxDevH1, devH1] = hhdev_h1(ax0, hx0, vhx0, xx0, wx, cxx, hAvgx, r, dV_da1, dV_dh1, a0(1), h0(1));

   if maxDevH1 > toler
      warnmsg(sprintf( 'Invalid investment in h1: %f', maxDevH1 ));
   end
end


% **************  HOUSEHOLDS  ***********************

   [devHh, maxDevHh] = bgdev_hh_og1(hhS,priceS,agS,dbg);
   if maxDevHh > toler
      warnmsg([ mfilename, ':  Invalid hh solution:  ', sprintf('%6f', maxDevHh) ]);
   end


% ========================  SPECIAL CASES  =====================================


% ***********  REPLICATING INFINITE HORIZON?  ************************
% These conditions check whether the model replicates a representative agent economy.
% They only apply with full altruism and heritability of hc.

if 0
    % *** Labor supply ***
    % Labor supply of each generation should be the same
    % I.e., total L = popSize * (individual L)
    L1 = popSize * wt0(1) * h0(1);
    if notequal(L, L1, 5e-3)
        tmp = sprintf('L: %6.3f    L1: %6.3f   %%-Diff. %6.3f', L, L1, (L/L1-1)*100);
        warnmsg('BgpChk', 'Labor supplies not equal', tmp);
    end

    % *** Hc growth ***
    % Individual h should grow at the rate of gr0
    hGr = h0(2:T) ./ h0(1:T-1);
    if notequal(hGr, gr0, 5e-3)
        warnmsg('BgpChk', 'H growth not equal gr0');
        hGr
        gr0
    end
end


% ***********  CHECK JMR'S FOC'S  **************
% MATLAB CANNOT EXECUTE THE FILES IN THE JMR DIRECTORY!!!! (NAME CONFLICTS).
% Therefor: Save the variables characterizing the bgp in a file in that directory.
% Then: MANUALLY (!!!) switch to that directory and run another program to actually check
% results. This is NOT A JOKE.
%
% The values saved are per PERIOD values, not per ANNUM values! Compare with the right ones
% from OLG output.

if 0
    % Transform into per period values
%    [gr0,r,w, c0,x0,l0,v0,Tr0] = pperiod(gr0, r,w, c0,x0,l0,v0,Tr0, yPerPd);
%    wt0 = wt0 ./ yPerPd;

    % Assemble the vector to be saved
    hAvg = h0(1);
    cx  = (1 - (1-xEarn).*(sx0 + tw0.*xDeduct) - tw0.*xEarn);
    K = K0./popSize;
    tax0JMR = [tw0,tk0,tc0, TrY0,GY0,DY0, sx0,xDeduct,xEarn,kDeduct, taxAdj];

    dev = hhdevjmr(r,w,hAvg, a0(1),h0(1), c0(1),wt0(1),v0(1),x0(1), a0(1)*gr0,h0(1)*gr0,...
        c0(1)*gr0,l0(1), Tr0(1),tc0(1),cx);
    disp(' ')
    disp('--- JMR HH Dev ---');
    disp(dev);

    disp(' ')
    disp('--- Some per period values ---');
    tmp = sprintf('   gr: %6.3f     r: %6.3f     K/L: %6.3f', gr0, r, K0(1)./L(1));
    disp(tmp);

    % Save
    tmp = [ r,w, hAvg, a0(1),h0(1), c0(1),wt0(1),v0(1),x0(1), a0(1)*gr0,h0(1)*gr0,...
        c0(1)*gr0,l0(1), Tr0(1),tc0(1),cx, K, tax0JMR ];
    save2( tmp, [jmrDir, 'olgres'] );
end


diary off;
% *** end function ***

