function [ojt, earn, wage, mtime] = bgpstats(l,v,h,x, wGr, T1, xEarn)
% Compute summary statistics characterizing a bgp
% ---------------------------------------
% IN:
%   representative household's life-cycle profiles
%   all variables: 1xT
% OUT:
%   Life-cycle profiles as a function of age in periods of:
%   - ojt   as a fraction of market time
%   - earnings
%   - wages
%   - market time


% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    dbg = 1;

% *** CONSTANTS ***

    T = length(v);
    if dbg > 0
        if T1<2 | T1>T
            T1
            abort('Invalid T1 (last argument)')
        end
        if xEarn>1  |  xEarn<0
            xEarn
            abort('xEarn invalid')
        end
    end

%    global yearsOfLife

%    yPerPd = yearsOfLife / T;

    % Eliminate rounding errors
    wt = max(1 - l - v, zeros(1,T));
    l  = min(l, ones(1,T));
    v  = min(v, 1-l);
    v  = max(v, 0);


% ******  OJT  *******

    ojt = v ./ ( (1-l) + ((1-l)<=0) );


% *******  GROSS EARNINGS  *******

%    earn = wt .* wGr .* h - x .* (1-tl);
    earn = wt .* wGr .* h - x.*xEarn;
%    if any(earn<0)
%        warnmsg('BgpStats: Negative earnings in some periods')
%        earn = max( earn, zeros(1,T) );
%    end


% *******  WAGES  **********
% Observed wages include ojt (time and expenditure) => must be corrected
% here.

    % Avoid division by zero when l=1 by setting observed work time to a
    % positive number when wt=0 (and earn=0)
    % Set wh= wGr.*h whenever earnings are zero
    % Not entirely satisfactory!! It is not clear what corresponds to ob-
    % served earnings because the part of (v,x) contained in it is unknown.
    % After age T1, assume that all (v,x) is out of the job.

    wage = wGr .* h;
    for t = 1 : T1
        if earn(t) > 0
            wage(t) = earn(t) / wt(t);
        %else
        %    wage(t) = wGr(t).*h(t);
        end
    end
%    wtObs = 1-l + 10 .* (l>=1);
%    wage = earn ./ wtObs + wGr.*h .* (earn<=0);



% *******  MARKET TIME  *********

    mtime = 1-l;

% *** end function ***

