function [deficit,rev,expend] = govbc(G,Tr,D, C,X,K,L,Lold,Xold, tw,tk,to,tc,sx,...
    xEarn,xDeduct, kDeduct,ddk, Xx,sxx)
% Government revenue, expenditure, deficit
% ---------------------------------------
% IN:
%   D       = 1xN+1 or 1xN. Then it is assumed that D(N+1) grows at the same
%       rate as at date N
% OUT:
%

% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    dbg = 0;

    global bequ
    if bequ > 0
        disp('GovBc: Not adapted for bequest taxes!');
    end

    N = length(K);
    [ Y, MPK, MPL ] = prodfct(K,L);
    Ynet = Y - ddk .* K;
    r1 = 1 + netr(MPK, tk, kDeduct, ddk);

    xSubsidy = sx.*(1-xEarn).*X;
    xxSubsidy = sxx .* Xx;
    tcRev = tc .* C;
    tkRev = ktax(MPK, K, tk, ddk, kDeduct);
    twRev = ltax(MPL, L, X, tw, xDeduct,xEarn);
    toRev = ltax(MPL, Lold, Xold, to, xDeduct,xEarn);
    DSpend = D(1:N) .* r1;
    if length(D) > N
        D1 = D(2:N+1);
    else
        D1 = [ D(2:N), D(N)./D(N-1).*D(N) ];
    end

    expend  = G + Tr + xSubsidy + xxSubsidy + DSpend;
    rev     = tcRev + twRev + toRev + tkRev + D1;
    deficit = expend - rev;


% ********  SHOW REVENUE SHARES  *********

    if dbg > 0
        Ynet  = prodfct(K, L) - ddk.*K;
        disp('TaxRev: Tax revenue shares in Ynet:');
        tmp = sprintf('tk: %6.3f   tw: %6.3f    tc: %6.3f    to: %6.3f', ...
            tkRev./Ynet, twRev./Ynet, tcRev./Ynet, toRev./Ynet);
        disp(tmp);
        tmp = sprintf('tb: %6.3f   sx: %6.3f   sum: %6.3f', ...
            0./Ynet, xSubsidy./Ynet, rev./Ynet);
        disp(tmp);
    end


% *** end function ***
