function [ xMean, xGrowth ] = pdavg(x, yub, yPerPd, dbg);
% Compute averages of a vector given in periods over year ranges
% ---------------------------------------
% IN:
%   x       vector; by periods
%   yub     upper bounds of intervals in years
%   yPerPd  years per period
% OUT:
%   xMean   average of x over year ranges defined by yub
%   xGrowth growth rate (+1) of averages

% REM:
%

% TEST:
%  t_pdavg.m
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

   if nargin < 4
      dbg = 1;
   end
   T = length(x);

   % Upper bounds in terms of periods:
   pub = round(yub ./ yPerPd);
   n = length(pub);
   pub(n) = min(pub(n), T);

   if dbg > 0
       if pub(1) <= 0
           warnmsg('PdAvg: pub(1) <= 0.')
       end
       for i = 1 : n-1
           if pub(i) >= pub(i+1)
               [i, pub(i), pub(i+1)]
               abort('PdAvg: Identical pd upper bounds.')
           end
       end
   end

   % Mean x over periods
   xMean   = [ mean(x(1:pub(1))), zeros(1,n-1) ];
   xGrowth = zeros(1,n-1);
   for i = 1 : n-1
       xMean(i+1) = mean( x(pub(i)+1:pub(i+1)) );
       xGrowth(i) = xMean(i+1) / xMean(i);
   end


   if 0
       pub
       xMean
       xGrowth
   end


% *** end function ***

