function polOk = polchk(tw,to,tc,tk, ts,RR, DY,TrY,GY, N)
% Check consistency of policy paths
% ---------------------------------------
% IN:
%   paths of length N for all policy variables
% OUT:
%   polOk
%       variable that indicates whether problems were found
%       1 = OK; 2 = Warning; 3 = fatal error

% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    polOk = 1;

    taxVec = [tw,to,tc,tk];
    polVec = [ taxVec, ts,RR, DY,TrY,GY ];

    if size(polVec,2) ~= 9*N
        warnmsg('polchk: Invalid input dimension')
        colNo = size(polVec,2);
        disp([ 'Columns:  Soll: ', int2str(9*N), '  Ist: ', int2str(colNo) ])
        tw
        tk
        TrY
        GY
        tc
        to
        DY
        ts
        RR
        polOk = 3;
    end

    if any(taxVec<0)
        warnmsg('polchk: Negative tax rates')
        tmp = sprintf('Min. tw: %5.3f,  to: %5.3f,  tc: %5.3f,  tk: %5.3f',...
            min(tw), min(to), min(tc), min(tk));
        disp(tmp)
        polOk = 3;
    end
    if any(taxVec>1)
        warnmsg('polchk: Tax rates > 1')
        tmp = sprintf('Max. tw: %5.3f,  to: %5.3f,  tc: %5.3f,  tk: %5.3f',...
            max(tw), max(to), max(tc), max(tk));
        disp(tmp)
        polOk = 3;
    end
    if any(ts<0) | any(ts>1) | any(RR<0)
        warnmsg('polchk: Invalid SS policies')
        tmp = sprintf('ts: %5.3f - %5.3f,  RR: %5.3f - %5.3f',...
            min(ts), max(ts), min(RR), max(RR));
        disp(tmp)
        polOk = 3;
    end
    if any(GY<-0.001) | any(GY>=1) | any(TrY<=-1) | any(TrY>=1)
        warnmsg('polchk: Invalid spending policies')
        tmp = sprintf('GY: %5.3f - %5.3f,  TrY: %5.3f - %5.3f',...
            min(GY), max(GY), min(TrY), max(TrY));
        disp(tmp)
        polOk = 3;
    end

    if polOk == 3
        disp('polchk: Fatal error. Aborting recommended')
        disp('        Or press any key to continue')
        pause
    end


% *** end function ***
