function t_hhprb(TESTCASE)
% t_hhprb: Test hhproblm()
% ---------------------------------------
% TASK:
%       Test hhprobl()
% IN:
%       -
% OUT:
%       -

% REM:
% ERRORS:
%
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

% *** CONSTANTS ***

    global yearsOfLife
    global baseDir outDir

    abort('Not updated.');
    diaryon('t_hh');

% ***** Initial guesses *****

    % ** Defaults
        phiIni  = [];
        hIni    = [];

    if  TESTCASE == 1
        % ****** Corner case ******
        T = 8;
        og1para(1,T);
        % comppara( T, [],[],[],[] );
        hc1 = 1;
        a1  = 10.10;
        Tr  = seqa(0.3, 0.01, T);
        w   = seqa(2.01, 0.03, T);
        r   = seqa(1.03 ^ floor(yearsOfLife/T) - 1, 0.02, T);
        tw  = ones(1,T) .* 0.13;
        tc  = zeros(1,T);
        SSI = zeros(1,T);
        c1Ini  = [];
        muIni  = [];
        phiIni   = [];
        hhProbTol = 1e-5;

    elseif  TESTCASE == 2
        % ****** No social security and cons. tax ******
        T = 10;
        og1para(1,T);
        % comppara( T, [],[],[],[] );
        hc1 = 1;
        a1  = 0;
        Tr  = seqa(0.0013, 0.0001, T);
        r   = seqa(1.06 ^ floor(yearsOfLife/T) - 1, 0.005, T);
        w   = seqa(3.01, 0.03, T);
        tw  = seqm(0.13, 0.9, T);
        tc  = zeros(1,T);
        SSI = zeros(1,T);
        c1Ini  = [];
        muIni  = [];
        hhProbTol = 1e-5;

    elseif  TESTCASE == 3
        % ****** Simple case ******
        T = 4;
        og1para(1,T);
        % comppara( T, [],[],[],[] );
        hc1 = 1;
        a1  = 0;
        Tr  = zeros(1,T);
        w   = ones(1,T) .* 2.1;
        r   = seqa(1.03 ^ floor(yearsOfLife/T) - 1, 0.02, T);
        tw  = zeros(1,T);
        SSI = zeros(1,T);
        tc  = zeros(1,T);
        c1Ini  = [];
        muIni  = [];
        phiIni = [];
        hhProbTol = 1e-5;

    elseif  TESTCASE == 4
        % ****** Long Simple case ******
        T = 25;
        og1para(1,T);
        % comppara( T, [],[],[],[] );
        hc1 = 1;
        a1  = 0;
        Tr  = zeros(1,T);
        r   = ones(1,T) .* (1.065 .^ floor(yearsOfLife/T)) - 1;
        w   = r .* 1.5;
        tw  = zeros(1,T);
        SSI = zeros(1,T);
        tc  = zeros(1,T);
        c1Ini  = [];
        muIni  = [];
        hhProbTol = 1e-5;

    else
        abort('Invalid TESTCASE')
    end


% ******  CHECK THAT EVERYTHING IS INITIALIZED  *********

    tmp = [w,r,tw,tc,SSI,Tr];
    if length(tmp)~=6*T
        abort('Not everything initialized')
    end


% ******  SHOW SETTINGS  ************************************

        diaryon([ outDir, 'test' ]);
        disp(' ')
        disp('-----------  t_hhprb: Start  ------------')

    disp([ '   r = ', num2str(r(1)), ' -> ', num2str(r(T)) ])
    disp([ '   w = ', num2str(w(1)), ' -> ', num2str(w(T)) ])
    disp([ '  tw = ', num2str(tw(1)), ' -> ', num2str(tw(T)) ])
    tmp = sprintf('  h1 = %5.2f', hc1(1) );
    disp(tmp);


% **************  SOLVE  ************************

    [c0, l0, v0, a0, h0, x0, c1, phi] = hhprob...
        (w, r, tw,tc,SSI, Tr,hc1(1),a1(1), c1Ini,muIni,phiIni,hIni, hhProbTol);

    hc1 = h0;
    a1 = a0;

    disp(' ')
    disp('--- SOLUTION OF HH PROBLEM ---')
    matprint( [c0',l0',v0',(1-l0-v0)',a0',h0',x0'], hhProbTol/100, ...
    '       -c-       -l-       -v-      -wt-       -a-       -h-       -x-' );



diary off
% *** end function ***

